<br/>
<p align="center">
  <a>
    <img src="https://static.ston.fi/favicon/android-chrome-512x512.png" alt="Logo" width="80" height="80">
  </a>
  <h3 align="center">StonFi Python SDK</h3>
</p>



### Testnet

- Faucet: https://t.me/testgiver_ton_bot
- Explorer: https://testnet.tonviewer.com/
- Proxy Ton Address: [kQAcOvXSnnOhCdLYc6up2ECYwtNNTzlmOlidBeCs5cFPV7AM](https://testnet.tonviewer.com/kQAcOvXSnnOhCdLYc6up2ECYwtNNTzlmOlidBeCs5cFPV7AM)
- StonFi Router Address: [kQBsGx9ArADUrREB34W-ghgsCgBShvfUr4Jvlu-0KGc33a1n](https://testnet.tonviewer.com/kQBsGx9ArADUrREB34W-ghgsCgBShvfUr4Jvlu-0KGc33a1n)
